@@ -100,7 +100,7 @@ class Loader(threading.Thread):
 					for i in ["|", "/", "-", "\\"]:
 						if not self.released: break
 						if self.message != self.last_message:
-							print(self.__empty_message__(length=len(f"{self.message} ...   ")), end="\r")
+							print(self.__empty_message__(length=len(f"{self.last_message} ...   ")), end="\r")
 							self.message = self.__clean_message__(self.message)
 						print(f"{self.message} ... {i}", end="\r")
 						self.last_message = self.message
